==> certmanager-model-v1alpha3-6.7.2-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ACMEChallengeSolverHTTP01IngressTemplateBuilder.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ACMEChallengeSolverHTTP01IngressTemplateBuilder extends ACMEChallengeSolverHTTP01IngressTemplateFluentImpl<ACMEChallengeSolverHTTP01IngressTemplateBuilder> implements VisitableBuilder<ACMEChallengeSolverHTTP01IngressTemplate,ACMEChallengeSolverHTTP01IngressTemplateBuilder>{
  public ACMEChallengeSolverHTTP01IngressTemplateBuilder() {
    this(false);
  }
  public ACMEChallengeSolverHTTP01IngressTemplateBuilder(Boolean validationEnabled) {
    this(new ACMEChallengeSolverHTTP01IngressTemplate(), validationEnabled);
  }
  public ACMEChallengeSolverHTTP01IngressTemplateBuilder(ACMEChallengeSolverHTTP01IngressTemplateFluent<?> fluent) {
    this(fluent, false);
  }
  public ACMEChallengeSolverHTTP01IngressTemplateBuilder(ACMEChallengeSolverHTTP01IngressTemplateFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ACMEChallengeSolverHTTP01IngressTemplate(), validationEnabled);
  }
  public ACMEChallengeSolverHTTP01IngressTemplateBuilder(ACMEChallengeSolverHTTP01IngressTemplateFluent<?> fluent,ACMEChallengeSolverHTTP01IngressTemplate instance) {
    this(fluent, instance, false);
  }
  public ACMEChallengeSolverHTTP01IngressTemplateBuilder(ACMEChallengeSolverHTTP01IngressTemplateFluent<?> fluent,ACMEChallengeSolverHTTP01IngressTemplate instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ACMEChallengeSolverHTTP01IngressTemplateBuilder(ACMEChallengeSolverHTTP01IngressTemplate instance) {
    this(instance,false);
  }
  public ACMEChallengeSolverHTTP01IngressTemplateBuilder(ACMEChallengeSolverHTTP01IngressTemplate instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  ACMEChallengeSolverHTTP01IngressTemplateFluent<?> fluent;
  Boolean validationEnabled;
  public ACMEChallengeSolverHTTP01IngressTemplate build() {
    ACMEChallengeSolverHTTP01IngressTemplate buildable = new ACMEChallengeSolverHTTP01IngressTemplate(fluent.getMetadata());
    return buildable;
  }
  
}

==> certmanager-model-v1alpha3-6.8.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ACMEChallengeSolverHTTP01IngressTemplateBuilder.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ACMEChallengeSolverHTTP01IngressTemplateBuilder extends ACMEChallengeSolverHTTP01IngressTemplateFluent<ACMEChallengeSolverHTTP01IngressTemplateBuilder> implements VisitableBuilder<ACMEChallengeSolverHTTP01IngressTemplate,ACMEChallengeSolverHTTP01IngressTemplateBuilder>{
  public ACMEChallengeSolverHTTP01IngressTemplateBuilder() {
    this(false);
  }
  public ACMEChallengeSolverHTTP01IngressTemplateBuilder(Boolean validationEnabled) {
    this(new ACMEChallengeSolverHTTP01IngressTemplate(), validationEnabled);
  }
  public ACMEChallengeSolverHTTP01IngressTemplateBuilder(ACMEChallengeSolverHTTP01IngressTemplateFluent<?> fluent) {
    this(fluent, false);
  }
  public ACMEChallengeSolverHTTP01IngressTemplateBuilder(ACMEChallengeSolverHTTP01IngressTemplateFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ACMEChallengeSolverHTTP01IngressTemplate(), validationEnabled);
  }
  public ACMEChallengeSolverHTTP01IngressTemplateBuilder(ACMEChallengeSolverHTTP01IngressTemplateFluent<?> fluent,ACMEChallengeSolverHTTP01IngressTemplate instance) {
    this(fluent, instance, false);
  }
  public ACMEChallengeSolverHTTP01IngressTemplateBuilder(ACMEChallengeSolverHTTP01IngressTemplateFluent<?> fluent,ACMEChallengeSolverHTTP01IngressTemplate instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ACMEChallengeSolverHTTP01IngressTemplate());

    if (instance != null) {
      fluent.withMetadata(instance.getMetadata());
      fluent.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ACMEChallengeSolverHTTP01IngressTemplateBuilder(ACMEChallengeSolverHTTP01IngressTemplate instance) {
    this(instance,false);
  }
  public ACMEChallengeSolverHTTP01IngressTemplateBuilder(ACMEChallengeSolverHTTP01IngressTemplate instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ACMEChallengeSolverHTTP01IngressTemplate());

    if (instance != null) {
      this.withMetadata(instance.getMetadata());
      this.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  ACMEChallengeSolverHTTP01IngressTemplateFluent<?> fluent;
  Boolean validationEnabled;
  public ACMEChallengeSolverHTTP01IngressTemplate build() {
    ACMEChallengeSolverHTTP01IngressTemplate buildable = new ACMEChallengeSolverHTTP01IngressTemplate(fluent.buildMetadata());
    return buildable;
  }
  
}
